@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Git::Repository;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 # the list of CPAN.pm methods we will replace
 my %cpan;
@@ -15,7 +15,13 @@ my %hook = (
 my @keys = qw( __HOOK__ );
 
 # if we were called from within CPAN.pm's configuration
-if ( $INC{'CPAN.pm'} ) {
+_TSR_CPAN() if $INC{'CPAN.pm'};
+
+#
+# some private utilities
+#
+sub _TSR_CPAN {
+    require CPAN;
 
     # actually replace the code in CPAN.pm
     _replace( $_ => $hook{$_} ) for keys %hook;
@@ -24,10 +30,6 @@ if ( $INC{'CPAN.pm'} ) {
     $CPAN::HandleConfig::keys{$_} = undef for @keys;
 }
 
-#
-# some private utilities
-#
-
 sub _replace {
     my ( $fullname, $meth ) = @_;
     my $name = ( split /::/, $fullname )[-1];
@@ -95,14 +97,14 @@ sub init {
 #
 
 sub install {
-    require CPAN;
+    _TSR_CPAN;
     CPAN::HandleConfig->load();
     $CPAN::Config->{__HOOK__} = sub { };
     CPAN::HandleConfig->commit();
 }
 
 sub uninstall {
-    require CPAN;
+    _TSR_CPAN;
     CPAN::HandleConfig->load();
     delete $CPAN::Config->{$_} for @keys;
     CPAN::HandleConfig->commit();
